@@ -1,5 +1,5 @@
 # This file is part of Pebble.
-# Copyright (c) 2013-2024, Matteo Cafasso
+# Copyright (c) 2013-2025, Matteo Cafasso
 
 # Pebble is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License
@@ -76,7 +76,7 @@ class BasePool:
             self.stop()
             self.join()
         else:
-            self._context.task_queue.put(None)
+            self._context.task_queue.put(None)  # Pool termination sentinel
             self._stop_pool()
 
     def _wait_queue_depletion(self, timeout: Optional[float]):
